<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Pierogi
 */

get_header();

$pierogi_page_title = is_front_page() ? esc_html__( 'Blog', 'pierogi' ) : get_the_title( get_option( 'page_for_posts' ) );

?>

	<header class="page-header">
		<h1 class="page-title screen-reader-text"><?php echo esc_html( $pierogi_page_title ); ?></h1>

		<?php

		if ( function_exists( 'the_subtitle' ) ) {
			the_subtitle( '<p class="entry-subtitle featured">', '</p>' );
		}

		?>

	</header>
	<div id="primary" class="content-area">
		<main id="main" class="site-main">


		<?php

		if ( have_posts() ) :
			/* Start the Loop */
			while ( have_posts() ) :
				the_post();

				/*
				 * Include the Post-Type-specific template for the content.
				 * If you want to override this in a child theme, then include a file
				 * called content-___.php (where ___ is the Post Type name) and that will be used instead.
				 */
				get_template_part( 'template-parts/content', get_post_type() );

			endwhile;

			the_posts_pagination( [ 'mid_size' => 2 ] );

		else :

			get_template_part( 'template-parts/content', 'none' );

		endif;
		?>

		</main><!-- #main -->


	<?php
		pierogi_display_sidebar();
	?>

	</div><!-- #primary -->

<?php
get_footer();
